@@ -13,6 +13,7 @@ from aiohttp import ClientResponse, ClientSession
 from pyhoma.exceptions import (
     BadCredentialsException,
     NotAuthenticatedException,
+    TooManyExecutionsException,
     TooManyRequestsException,
 )
 from pyhoma.models import Command, Device, Event, Execution, Scenario, State
@@ -114,6 +115,15 @@ class TahomaClient:
 
         return state
 
+    @backoff.on_exception(
+        backoff.expo, NotAuthenticatedException, max_tries=2, on_backoff=relogin
+    )
+    async def refresh_states(self) -> None:
+        """
+        Ask the box to refresh all devices states for protocols supporting that operation
+        """
+        await self.__post("/setup/devices/states/refresh")
+
     async def register_event_listener(self) -> str:
         """
         Register a new setup event listener on the current session and return a new
@@ -248,7 +258,7 @@ class TahomaClient:
     @staticmethod
     async def check_response(response: ClientResponse) -> None:
         """ Check the response returned by the TaHoma API"""
-        if response.status == 200:
+        if response.status in [200, 204]:
             return
 
         try:
@@ -275,4 +285,8 @@ class TahomaClient:
             if message == "Not authenticated":
                 raise NotAuthenticatedException(message)
 
+            # {"error": "Server busy, please try again later. (Too many executions)"}
+            if message == "Server busy, please try again later. (Too many executions)":
+                raise TooManyExecutionsException(message)
+
             raise Exception(message if message else result)
